#
# Copyright (c) 2020 Xilinx, Inc. All rights reserved.
# SPDX-License-Identifier: MIT
#

from roast.machines.zynqmp import *

dtb_dtg = "zcu208-reva"
silicon = "zu48dr-prod"
uboot_devicetree = "zynqmp-zcu208-revA"

PLNX_BSP = "xilinx-zcu208-v{version}-final.bsp"
plnx_proj = "xilinx-zcu208-{version}"
